summaryrefslogtreecommitdiff
path: root/src/block/block_slvg.c
diff options
context:
space:
mode:
authorKeith Bostic <keith@wiredtiger.com>2012-06-19 12:55:55 +0000
committerKeith Bostic <keith@wiredtiger.com>2012-06-19 12:55:55 +0000
commit1964a22e5a96ca7e8b77e622da339710d169b01c (patch)
tree0a61cbb27e26a49d75094220247e134782a75cb0 /src/block/block_slvg.c
parent64186d4ae9ad0a92aaa992c289fdeafb191cacd8 (diff)
downloadmongo-1964a22e5a96ca7e8b77e622da339710d169b01c.tar.gz
Push snapshot to checkpoint rename down through the rest of the system
(except for the transaction code).
Diffstat (limited to 'src/block/block_slvg.c')
-rw-r--r--src/block/block_slvg.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/block/block_slvg.c b/src/block/block_slvg.c
index 0a44731d5aa..0d87232d15e 100644
--- a/src/block/block_slvg.c
+++ b/src/block/block_slvg.c
@@ -21,10 +21,10 @@ __wt_block_salvage_start(WT_SESSION_IMPL *session, WT_BLOCK *block)
WT_RET(__wt_desc_init(session, block->fh));
/*
* Salvage creates a new snapshot when it's finished, set up for
* rolling an empty file forward.
*/
- WT_RET(__wt_block_snap_init(session, block, &block->live, "live", 1));
+ WT_RET(__wt_block_ckpt_init(session, block, &block->live, "live", 1));
/*
* Truncate the file to an initial sector plus N allocation size
@@ -48,9 +48,9 @@ __wt_block_salvage_start(WT_SESSION_IMPL *session, WT_BLOCK *block)
block->slvg_off = WT_BLOCK_DESC_SECTOR;
/*
* The only snapshot extent we care about is the allocation list. Start
* with the entire file on the allocation list, we'll "free" any blocks
* we don't want as we process the file.
*/
WT_RET(__wt_block_insert_ext(session, &block->live.alloc,
WT_BLOCK_DESC_SECTOR, len - WT_BLOCK_DESC_SECTOR));
@@ -70,8 +70,8 @@ __wt_block_salvage_end(WT_SESSION_IMPL *session, WT_BLOCK *block)
block->slvg = 0;
- /* Discard the snapshot. */
- return (__wt_block_snapshot_unload(session, block));
+ /* Discard the checkpoint. */
+ return (__wt_block_checkpoint_unload(session, block));
}
/*
@@ -21,10 +21,10 @@ __wt_block_salvage_start(WT_SESSION_IMPL *session, WT_BLOCK *block)
WT_RET(__wt_desc_init(session, block->fh));
/*
- * Salvage creates a new snapshot when it's finished, set up for
+ * Salvage creates a new checkpoint when it's finished, set up for
* rolling an empty file forward.
*/
@@ -48,9 +48,9 @@ __wt_block_salvage_start(WT_SESSION_IMPL *session, WT_BLOCK *block)
block->slvg_off = WT_BLOCK_DESC_SECTOR;
/*
- * The only snapshot extent we care about is the allocation list. Start
- * with the entire file on the allocation list, we'll "free" any blocks
- * we don't want as we process the file.
+ * The only checkpoint extent we care about is the allocation list.
+ * Start with the entire file on the allocation list, we'll "free"
+ * any blocks we don't want as we process the file.
*/
WT_RET(__wt_block_insert_ext(session, &block->live.alloc,